@@ -85,7 +85,7 @@ class SettingsPageColor : public QWidget, public Ui::SettingsPageColor
     : QWidget( parent )
         {
 			setupUi(this);
-			layout()->setMargin(0);
+			layout()->setContentsMargins(0, 0, 0, 0);
 		}
 };
 
@@ -96,7 +96,7 @@ class SettingsPageFonts : public QWidget, public Ui::SettingsPageFonts
 	: QWidget( parent )
 		{
 			setupUi(this);
-			layout()->setMargin(0);
+			layout()->setContentsMargins(0, 0, 0, 0);
 		}
 };
 
@@ -107,7 +107,7 @@ class SettingsPageGeneral : public QWidget, public Ui::SettingsPageGeneral
 	: QWidget( parent )
 		{
 			setupUi(this);
-                        layout()->setMargin(0);
+                        layout()->setContentsMargins(0, 0, 0, 0);
 		}
 };
 
@@ -118,7 +118,7 @@ class SettingsPageDiagram : public QWidget, public Ui::SettingsPageDiagram
 	: QWidget( parent )
 		{
 			setupUi(this);
-			layout()->setMargin(0);
+			layout()->setContentsMargins(0, 0, 0, 0);
 		}
 };
 
@@ -725,7 +725,7 @@ void MainDlg::slotPrintPreview()
 		QAction *printSettings = toolbarlist.first()->addAction( QIcon::fromTheme( "configure" ), i18n("Print Settings") );
 		QList<QPrintPreviewWidget*> previewWidgetsList = preview->findChildren<QPrintPreviewWidget*>();
 		QPrintPreviewWidget *previewWidget = previewWidgetsList.first();
-		connect( printSettings, &QAction::triggered, [preview, previewWidget, printdlg, &prt]{
+		connect( printSettings, &QAction::triggered, [preview, previewWidget, printdlg]{
 			QDialog *printSettingsDialog = new QDialog( preview, Qt::WindowFlags() );
 			printSettingsDialog->setWindowTitle( i18n("Print Settings") );
 			QVBoxLayout *mainLayout = new QVBoxLayout;
